@@ -137,6 +137,7 @@ list_scan_type = [
     "SSLyze Scan (JSON)",
     "StackHawk HawkScan",
     "Talisman Scan",
+    "Tenable Scan",
     "Terrascan Scan",
     "Testssl Scan",
     "TFSec Scan",
@@ -219,6 +220,7 @@ class ImportScanSerializer(Schema):
     project_remote_config = fields.Str(required=False)
     # regulare expression
     expression = fields.Str(required=True)
+    reimport_scan = fields.Bool(required=False, default=False)
 
     @post_load
     def make_cmdb(self, data, **kwargs):
